lmi-commits
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[lmi-commits] [5118] Share download cache across Cygwin versions


From: Greg Chicares
Subject: [lmi-commits] [5118] Share download cache across Cygwin versions
Date: Thu, 04 Nov 2010 01:31:44 +0000

Revision: 5118
          http://svn.sv.gnu.org/viewvc/?view=rev&root=lmi&revision=5118
Author:   chicares
Date:     2010-11-04 01:31:43 +0000 (Thu, 04 Nov 2010)
Log Message:
-----------
Share download cache across Cygwin versions

Modified Paths:
--------------
    lmi/trunk/install_cygwin.bat
    lmi/trunk/install_libxml2_libxslt.make
    lmi/trunk/install_miscellanea.make
    lmi/trunk/install_mpatrol.make
    lmi/trunk/install_msw.sh
    lmi/trunk/install_wx.make

Modified: lmi/trunk/install_cygwin.bat
===================================================================
--- lmi/trunk/install_cygwin.bat        2010-11-04 00:49:15 UTC (rev 5117)
+++ lmi/trunk/install_cygwin.bat        2010-11-04 01:31:43 UTC (rev 5118)
@@ -73,9 +73,10 @@
   cvs,doxygen,gdb,libtool,make,openssh,patch,rsync,subversion,wget,zsh
 cd C:\cygwin-1_7\etc
 echo # >> fstab
-echo C:/opt/lmi/MinGW-20090203 /MinGW_  lmi_specific binary,user 0 0 >> fstab
-echo C:/opt/lmi                /opt/lmi lmi_specific binary,user 0 0 >> fstab
-echo C:/lmi                    /lmi     lmi_specific binary,user 0 0 >> fstab
+echo C:/opt/lmi/MinGW-20090203 /MinGW_        lmi_specific binary,user 0 0 >> 
fstab
+echo C:/opt/lmi                /opt/lmi       lmi_specific binary,user 0 0 >> 
fstab
+echo C:/lmi                    /lmi           lmi_specific binary,user 0 0 >> 
fstab
+echo C:/cache_for_lmi          /cache_for_lmi lmi_specific binary,user 0 0 >> 
fstab
 cd C:\cache_for_lmi
 echo Cygwin-1.7 installation seems to have succeeded
 GOTO End

Modified: lmi/trunk/install_libxml2_libxslt.make
===================================================================
--- lmi/trunk/install_libxml2_libxslt.make      2010-11-04 00:49:15 UTC (rev 
5117)
+++ lmi/trunk/install_libxml2_libxslt.make      2010-11-04 01:31:43 UTC (rev 
5118)
@@ -35,7 +35,7 @@
 
 prefix        := /opt/lmi/local
 
-cache_dir     := /tmp/lmi_cache
+cache_dir     := /cache_for_lmi/downloads
 
 xml_dir       := /opt/lmi/xml-scratch
 

Modified: lmi/trunk/install_miscellanea.make
===================================================================
--- lmi/trunk/install_miscellanea.make  2010-11-04 00:49:15 UTC (rev 5117)
+++ lmi/trunk/install_miscellanea.make  2010-11-04 01:31:43 UTC (rev 5118)
@@ -25,7 +25,7 @@
 
 prefix    := /opt/lmi
 
-cache_dir := /tmp/lmi_cache
+cache_dir := /cache_for_lmi/downloads
 
 # In the past, it seemed necessary to specify a mirror, e.g.:
 #  mirror := http://easynews.dl.sourceforge.net/sourceforge

Modified: lmi/trunk/install_mpatrol.make
===================================================================
--- lmi/trunk/install_mpatrol.make      2010-11-04 00:49:15 UTC (rev 5117)
+++ lmi/trunk/install_mpatrol.make      2010-11-04 01:31:43 UTC (rev 5118)
@@ -33,7 +33,7 @@
 
 prefix          := $(mingw_dir)
 
-cache_dir       := /tmp/lmi_cache
+cache_dir       := /cache_for_lmi/downloads
 
 mpatrol_dir     := /opt/lmi/mpatrol-scratch
 

Modified: lmi/trunk/install_msw.sh
===================================================================
--- lmi/trunk/install_wx.make   2010-11-04 00:49:15 UTC (rev 5117)
+++ lmi/trunk/install_wx.make   2010-11-04 01:31:43 UTC (rev 5118)
@@ -31,7 +31,7 @@
 
 prefix        := /opt/lmi/local
 
-cache_dir     := /tmp/lmi_cache
+cache_dir     := /cache_for_lmi/downloads
 
 wx_dir        := /opt/lmi/wx-scratch
 




reply via email to

[Prev in Thread] Current Thread [Next in Thread]
--- lmi/trunk/install_msw.sh    2010-11-04 00:49:15 UTC (rev 5117)
+++ lmi/trunk/install_msw.sh    2010-11-04 01:31:43 UTC (rev 5118)
@@ -33,13 +33,13 @@
 #
 # rm --force --recursive /opt/lmi
 #
 # Downloaded archives are left in /tmp/lmi_cache because they are
 # costly to download and some host might be temporarily unavailable.
 
 date -u +'%Y%m%dT%H%MZ'
 
-md5sum $0
-find /tmp/lmi_cache -type f | xargs md5sum
+mkdir --parents /cache_for_lmi/downloads
 
 # Establish mounts carefully.
 #
@@ -65,8 +65,6 @@
 
 [ -z "$restore_opt_mount" ] || sh -c $restore_opt_mount
 
-mkdir --parents /tmp/lmi_cache
-
 cygcheck -s -v -r | tr --delete '\r'
 
 java -version
@@ -112,19 +110,29 @@
 
 cd /opt/lmi/src/lmi
 
-# A "Replacing former MinGW_ mount:" message probably means that this
+# A "Replacing former [...] mount:" message probably means that this
 # mount was set by an earlier lmi installation; that can be ignored.
 # It seems quite unlikely that anyone who's building lmi would have
-# any other need for a mount with that name.
+# any other need for mounts with the names used here.
 
 restore_MinGW_mount=`mount --mount-commands | grep '"/MinGW_"'`
 [ -z "$restore_MinGW_mount" ] \
   || echo $restore_MinGW_mount | grep --silent '"C:/opt/lmi/MinGW-20090203"' \
-  || echo -e "Replacing former MinGW_ mount:\n  $restore_MinGW_mount" >/dev/tty
+  || echo -e "Replacing former MinGW_ mount:\n $restore_MinGW_mount" >/dev/tty
 mount --force "C:/opt/lmi/MinGW-20090203" "/MinGW_"
+
+restore_cache_mount=`mount --mount-commands | grep '"/cache_for_lmi"'`
+[ -z "$restore_cache_mount" ] \
+  || echo $restore_cache_mount | grep --silent '"C:/cache_for_lmi"' \
+  || echo -e "Replacing former cache mount:\n  $restore_cache_mount" >/dev/tty
+mount --force "C:/cache_for_lmi" "/cache_for_lmi"
+
+md5sum $0
+find /cache_for_lmi/downloads -type f | xargs md5sum
+
 rm --force --recursive scratch
 rm --force --recursive /MinGW_
-make prefix=/MinGW_ cache_dir=/tmp/lmi_cache -f install_mingw.make
+make prefix=/MinGW_ cache_dir=/cache_for_lmi/downloads -f install_mingw.make
 
 make -f install_miscellanea.make clobber
 make -f install_miscellanea.make
@@ -133,7 +141,7 @@
 
 make -f install_wx.make
 
-find /tmp/lmi_cache -type f | xargs md5sum
+find /cache_for_lmi/downloads -type f | xargs md5sum
 
 export         PATH=/opt/lmi/local/bin:/opt/lmi/local/lib:$PATH
 export 
@@ -33,13 +33,13 @@
 # rm --force --recursive /opt/lmi
 #
-# Downloaded archives are left in /tmp/lmi_cache because they are
-# costly to download and some host might be temporarily unavailable.
+# Downloaded archives are kept in /cache_for_lmi/downloads/ because
+# they are costly to download and some host might be temporarily
+# unavailable.
 
 date -u +'%Y%m%dT%H%MZ'
minimal_path=/opt/lmi/local/bin:/opt/lmi/local/lib:/usr/bin:/bin:/usr/sbin:/sbin

Modified: lmi/trunk/install_wx.make
===================================================================